==> jc-1.4.0.tar.gz: polyglot/util/ErrorLimitError.h <==
// public class polyglot.util.ErrorLimitError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 346d846eb3bf9fe4 polyglot_util_ErrorLimitError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_util_ErrorLimitError_H_
#define _JC_polyglot_util_ErrorLimitError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_ErrorLimitError$sub_refs	_jc_polyglot_util_ErrorLimitError$sub_refs;
typedef struct _jc_polyglot_util_ErrorLimitError$sub_nonrefs	_jc_polyglot_util_ErrorLimitError$sub_nonrefs;
typedef struct _jc_polyglot_util_ErrorLimitError$refs	_jc_polyglot_util_ErrorLimitError$refs;
typedef struct _jc_polyglot_util_ErrorLimitError$nonrefs	_jc_polyglot_util_ErrorLimitError$nonrefs;
typedef struct _jc_polyglot_util_ErrorLimitError$object	_jc_polyglot_util_ErrorLimitError$object;

typedef const struct _jc_polyglot_util_ErrorLimitError$vmethods	_jc_polyglot_util_ErrorLimitError$vmethods;
typedef const struct _jc_polyglot_util_ErrorLimitError$vtable	_jc_polyglot_util_ErrorLimitError$vtable;
typedef const struct _jc_polyglot_util_ErrorLimitError$vtype	_jc_polyglot_util_ErrorLimitError$vtype;

// Constructors
extern void _jc_polyglot_util_ErrorLimitError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_ErrorLimitError$object *);
extern void _jc_polyglot_util_ErrorLimitError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_ErrorLimitError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_util_ErrorLimitError$vmethods {
};

// Vtable
struct _jc_polyglot_util_ErrorLimitError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_ErrorLimitError$vmethods	polyglot_util_ErrorLimitError;
};

// Vtype
struct _jc_polyglot_util_ErrorLimitError$vtype {
	_jc_type			type;
	_jc_polyglot_util_ErrorLimitError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ErrorLimitError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_ErrorLimitError$refs {
    _jc_polyglot_util_ErrorLimitError$sub_refs	polyglot_util_ErrorLimitError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ErrorLimitError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ErrorLimitError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_ErrorLimitError$sub_nonrefs	polyglot_util_ErrorLimitError;
};

// Object instance structure
struct _jc_polyglot_util_ErrorLimitError$object {
	_jc_polyglot_util_ErrorLimitError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ErrorLimitError$vtype	*vtype;
	_jc_polyglot_util_ErrorLimitError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ErrorLimitError$vtype _jc_polyglot_util_ErrorLimitError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ErrorLimitError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ErrorLimitError$class_object;

#endif	/* _JC_polyglot_util_ErrorLimitError_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/ErrorLimitError.h <==
// public class polyglot.util.ErrorLimitError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 346d846eb3bf9fe4 polyglot_util_ErrorLimitError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_util_ErrorLimitError_H_
#define _JC_polyglot_util_ErrorLimitError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_ErrorLimitError$sub_refs	_jc_polyglot_util_ErrorLimitError$sub_refs;
typedef struct _jc_polyglot_util_ErrorLimitError$sub_nonrefs	_jc_polyglot_util_ErrorLimitError$sub_nonrefs;
typedef struct _jc_polyglot_util_ErrorLimitError$refs	_jc_polyglot_util_ErrorLimitError$refs;
typedef struct _jc_polyglot_util_ErrorLimitError$nonrefs	_jc_polyglot_util_ErrorLimitError$nonrefs;
typedef struct _jc_polyglot_util_ErrorLimitError$object	_jc_polyglot_util_ErrorLimitError$object;

typedef const struct _jc_polyglot_util_ErrorLimitError$vmethods	_jc_polyglot_util_ErrorLimitError$vmethods;
typedef const struct _jc_polyglot_util_ErrorLimitError$vtable	_jc_polyglot_util_ErrorLimitError$vtable;
typedef const struct _jc_polyglot_util_ErrorLimitError$vtype	_jc_polyglot_util_ErrorLimitError$vtype;

// Constructors
extern void _jc_polyglot_util_ErrorLimitError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_ErrorLimitError$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_ErrorLimitError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_ErrorLimitError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_ErrorLimitError$vmethods {
};

// Vtable
struct _jc_polyglot_util_ErrorLimitError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_ErrorLimitError$vmethods	polyglot_util_ErrorLimitError;
};

// Vtype
struct _jc_polyglot_util_ErrorLimitError$vtype {
	_jc_type			type;
	_jc_polyglot_util_ErrorLimitError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ErrorLimitError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_ErrorLimitError$refs {
    _jc_polyglot_util_ErrorLimitError$sub_refs	polyglot_util_ErrorLimitError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ErrorLimitError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ErrorLimitError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_ErrorLimitError$sub_nonrefs	polyglot_util_ErrorLimitError;
};

// Object instance structure
struct _jc_polyglot_util_ErrorLimitError$object {
	_jc_polyglot_util_ErrorLimitError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ErrorLimitError$vtype	*vtype;
	_jc_polyglot_util_ErrorLimitError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ErrorLimitError$vtype _jc_polyglot_util_ErrorLimitError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ErrorLimitError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ErrorLimitError$class_object;

#endif	/* _JC_polyglot_util_ErrorLimitError_H_ */
